@@ -2,14 +2,15 @@
 # encoding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 0, 4)
+__version__ = (0, 0, 5)
 __all__ = [
-    "as_thread", "ensure_async", "ensure_await", "ensure_coroutine", "ensure_aiter", 
-    "async_map", "async_filter", "async_reduce", "async_zip", "async_chain", 
+    "run_async", "as_thread", "ensure_async", "ensure_await", 
+    "ensure_coroutine", "ensure_aiter", "async_map", "async_filter", 
+    "async_reduce", "async_zip", "async_chain", 
     "async_all", "async_any", "call_as_aiter", "to_list", 
 ]
 
-from asyncio import to_thread
+from asyncio import create_task, get_running_loop, run, to_thread
 from collections.abc import Awaitable, AsyncIterable, AsyncIterator, Callable, Coroutine, Iterable, Iterator
 from inspect import isawaitable, iscoroutine, iscoroutinefunction, isgenerator
 from typing import cast, Any, ParamSpec, TypeVar
@@ -22,6 +23,13 @@ Args = ParamSpec("Args")
 T = TypeVar("T")
 
 
+def run_async(obj, /):
+    if get_running_loop() is None:
+        return run(ensure_coroutine(obj))
+    else:
+        return create_task(ensure_coroutine(obj))
+
+
 @decorated
 def as_thread(
     func: Callable[Args, T], 
